@@ -2,7 +2,7 @@
     include  a multiple-line  comment
     in your code'''
 __author__ = 'qiuqiaohua'
-def print_lol(the_list,level):
+def print_lol(the_list,level=0):
     """
     递归输出列表的每个item
     """
